Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(192)

Unified Diff: tests/isolate/unresolved_ports_test.dart

Issue 218273002: Upgrading tests with unittest deprecations (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tests/isolate/unresolved_ports_test.dart
diff --git a/tests/isolate/unresolved_ports_test.dart b/tests/isolate/unresolved_ports_test.dart
index 8fe11c923d2800b2264676a20c82b0025febbb20..2ffa633f410ecbd10984358bbeefe4cb1b5803c0 100644
--- a/tests/isolate/unresolved_ports_test.dart
+++ b/tests/isolate/unresolved_ports_test.dart
@@ -18,7 +18,7 @@ import "remote_unittest_helper.dart";
bethIsolate(init) {
ReceivePort port = initIsolate(init);
// TODO(sigmund): use expectAsync2 when it is OK to use it within an isolate
// (issue #6856)
port.first.then((msg) => msg[1].send([
'${msg[0]}\nBeth says: Tim are you coming? And Bob?', msg[2]]));
@@ -54,7 +54,7 @@ ReceivePort initIsolate(SendPort starter) {
baseTest({bool failForNegativeTest: false}) {
test('Message chain with unresolved ports', () {
ReceivePort port = new ReceivePort();
- port.listen(expectAsync1((msg) {
+ port.listen(expectAsync((msg) {
expect(msg, equals('main says: Beth, find out if Tim is coming.'
'\nBeth says: Tim are you coming? And Bob?'
'\nTim says: Can you tell "main" that we are all coming?'
@@ -18,7 +18,7 @@ import "remote_unittest_helper.dart";
bethIsolate(init) {
ReceivePort port = initIsolate(init);
- // TODO(sigmund): use expectAsync2 when it is OK to use it within an isolate
+ // TODO(sigmund): use expectAsync when it is OK to use it within an isolate
// (issue #6856)
port.first.then((msg) => msg[1].send([

Powered by Google App Engine
This is Rietveld 408576698